==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QAdditiveClipBlend.java <==
package io.qt.qt3d.animation;


/**
 * <p>Performs an additive blend of two animation clips based on an additive factor</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html">Qt3DAnimation::QAdditiveClipBlend</a></p>
 */
public class QAdditiveClipBlend extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAdditiveClipBlend.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::additiveClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="additiveClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> additiveClipChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::additiveFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="additiveFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> additiveFactorChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::baseClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="baseClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> baseClipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAdditiveClipBlend(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAdditiveClipBlend() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAdditiveClipBlend(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAdditiveClipBlend instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::additiveClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="additiveClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip(){
        return additiveClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::additiveFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="additiveFactor")
    @io.qt.QtUninvokable
    public final float additiveFactor(){
        return additiveFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float additiveFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::baseClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="baseClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode baseClip(){
        return baseClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode baseClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::setAdditiveClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="additiveClip")
    public final void setAdditiveClip(io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip){
        setAdditiveClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(additiveClip));
    }
    
    private native void setAdditiveClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long additiveClip);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::setAdditiveFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="additiveFactor")
    public final void setAdditiveFactor(float additiveFactor){
        setAdditiveFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), additiveFactor);
    }
    
    private native void setAdditiveFactor_native_float(long __this__nativeId, float additiveFactor);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::setBaseClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="baseClip")
    public final void setBaseClip(io.qt.qt3d.animation.QAbstractClipBlendNode baseClip){
        setBaseClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(baseClip));
    }
    
    private native void setBaseClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long baseClip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAdditiveClipBlend(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAdditiveClipBlend(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAdditiveClipBlend instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2-sources.jar: io/qt/qt3d/animation/QAdditiveClipBlend.java <==
package io.qt.qt3d.animation;


/**
 * <p>Performs an additive blend of two animation clips based on an additive factor</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html">Qt3DAnimation::QAdditiveClipBlend</a></p>
 */
public class QAdditiveClipBlend extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAdditiveClipBlend.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::additiveClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="additiveClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> additiveClipChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::additiveFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="additiveFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> additiveFactorChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::baseClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="baseClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> baseClipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAdditiveClipBlend(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAdditiveClipBlend() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAdditiveClipBlend(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAdditiveClipBlend instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::additiveClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="additiveClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip(){
        return additiveClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::additiveFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="additiveFactor")
    @io.qt.QtUninvokable
    public final float additiveFactor(){
        return additiveFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float additiveFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::baseClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="baseClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode baseClip(){
        return baseClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode baseClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveClip-prop">Qt3DAnimation::QAdditiveClipBlend::setAdditiveClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="additiveClip")
    public final void setAdditiveClip(io.qt.qt3d.animation.QAbstractClipBlendNode additiveClip){
        setAdditiveClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(additiveClip));
    }
    
    private native void setAdditiveClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long additiveClip);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#additiveFactor-prop">Qt3DAnimation::QAdditiveClipBlend::setAdditiveFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="additiveFactor")
    public final void setAdditiveFactor(float additiveFactor){
        setAdditiveFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), additiveFactor);
    }
    
    private native void setAdditiveFactor_native_float(long __this__nativeId, float additiveFactor);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qadditiveclipblend.html#baseClip-prop">Qt3DAnimation::QAdditiveClipBlend::setBaseClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="baseClip")
    public final void setBaseClip(io.qt.qt3d.animation.QAbstractClipBlendNode baseClip){
        setBaseClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(baseClip));
    }
    
    private native void setBaseClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long baseClip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAdditiveClipBlend(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAdditiveClipBlend(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAdditiveClipBlend instance, QDeclarativeConstructor constructor);
    
}
